translate.storage.oo.ooline

Package translate :: Package storage :: Module oo :: Class ooline |
[hide private]
[frames] | no frames]

# Class ooline

source code

this represents one line, one translation in an .oo file

Instance Methods | [hide private]
__init__(self, parts=None) construct an ooline from its parts | source code
setparts(self, parts) create a line from its tab-delimited parts | source code
getparts(self) return a list of parts in this line | source code
gettext(self) Obtains the text column and handle escaping. | source code
settext(self, text) Sets the text column and handle escaping. | source code
__str__(self) convert to a string. | source code
getoutput(self) return a line in tab-delimited form | source code
getkey(self) get the key that identifies the resource | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Properties | [hide private]
| text Obtains the text column and handle escaping.
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, parts=None) (Constructor) | source code
construct an ooline from its parts Overrides: object.__init__

### __str__(self) (Informal representation operator) | source code
convert to a string. double check that unicode is handled Overrides: object.__str__

Property Details | [hide private]

### text Obtains the text column and handle escaping. Get Method: gettext(self) - Obtains the text column and handle escaping. Set Method: settext(self, text) - Sets the text column and handle escaping.